@@ -17,7 +17,7 @@
 package MongoDB::_Topology;
 
 use version;
-our $VERSION = 'v1.4.3';
+our $VERSION = 'v1.4.4';
 
 use Moo;
 use MongoDB::BSON;
@@ -605,7 +605,7 @@ sub _initialize_link {
     # we have a link and the server is a valid member, so
     # try to authenticate; if authentication fails, all
     # servers are considered invalid and we throw an error
-    if ( first { $_ eq $server->type } qw/Standalone Mongos RSPrimary RSSecondary/ ) {
+    if ( $self->type eq 'Single' || first { $_ eq $server->type } qw/Standalone Mongos RSPrimary RSSecondary/ ) {
         try {
             $self->credential->authenticate($link, $self->bson_codec);
         }
